@@ -5,13 +5,9 @@ use crate::{
     screen::NavMode,
     state::{root_menu, State},
     term::Term,
-    Res,
 };
-use derive_more::Display;
 use std::rc::Rc;
 
-#[derive(Display)]
-#[display(fmt = "Quit/Close")]
 pub(crate) struct Quit;
 impl OpTrait for Quit {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -49,10 +45,12 @@ impl OpTrait for Quit {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Quit/Close".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Submenu")]
 pub(crate) struct OpenMenu(pub crate::menu::Menu);
 impl OpTrait for OpenMenu {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -62,10 +60,12 @@ impl OpTrait for OpenMenu {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Submenu".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Refresh")]
 pub(crate) struct Refresh;
 impl OpTrait for Refresh {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -74,10 +74,12 @@ impl OpTrait for Refresh {
             state.screen_mut().update()
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Refresh".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = .0)]
 pub(crate) struct ToggleArg(pub String);
 impl OpTrait for ToggleArg {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -105,13 +107,24 @@ impl OpTrait for ToggleArg {
                 });
             }
 
+            let arg_name = arg_name.clone();
+            let parse_and_set_arg =
+                Box::new(move |state: &mut State, _term: &mut Term, value: &str| {
+                    if let Some(menu) = &mut state.pending_menu {
+                        if let Some(entry) = menu.args.get_mut(arg_name.as_str()) {
+                            return entry.set(value);
+                        }
+                    }
+
+                    Ok(())
+                });
+
             if let Some(display) = need_prompt {
                 set_prompt(
                     state,
                     display,
                     parse_and_set_arg,
                     Box::new(move |_| default.clone()),
-                    arg_name.clone(),
                     false,
                 );
             }
@@ -119,21 +132,12 @@ impl OpTrait for ToggleArg {
             Ok(())
         }))
     }
-}
 
-fn parse_and_set_arg(state: &mut State, _term: &mut Term, value: &str, arg: &String) -> Res<()> {
-    let key: &str = arg;
-    if let Some(menu) = &mut state.pending_menu {
-        if let Some(entry) = menu.args.get_mut(key) {
-            return entry.set(value);
-        }
+    fn display(&self, _state: &State) -> String {
+        self.0.clone()
     }
-
-    Ok(())
 }
 
-#[derive(Display)]
-#[display(fmt = "Toggle section")]
 pub(crate) struct ToggleSection;
 impl OpTrait for ToggleSection {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -143,10 +147,12 @@ impl OpTrait for ToggleSection {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Toggle section".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Up")]
 pub(crate) struct MoveUp;
 impl OpTrait for MoveUp {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -156,10 +162,12 @@ impl OpTrait for MoveUp {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Up".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Down")]
 pub(crate) struct MoveDown;
 impl OpTrait for MoveDown {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -169,10 +177,12 @@ impl OpTrait for MoveDown {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Down".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Down line")]
 pub(crate) struct MoveDownLine;
 impl OpTrait for MoveDownLine {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -182,10 +192,12 @@ impl OpTrait for MoveDownLine {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Down line".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Up line")]
 pub(crate) struct MoveUpLine;
 impl OpTrait for MoveUpLine {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -197,10 +209,12 @@ impl OpTrait for MoveUpLine {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Up line".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Next section")]
 pub(crate) struct MoveNextSection;
 impl OpTrait for MoveNextSection {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -211,10 +225,12 @@ impl OpTrait for MoveNextSection {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Next section".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Prev section")]
 pub(crate) struct MovePrevSection;
 impl OpTrait for MovePrevSection {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -227,10 +243,12 @@ impl OpTrait for MovePrevSection {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Prev section".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Parent section")]
 pub(crate) struct MoveParentSection;
 impl OpTrait for MoveParentSection {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -243,10 +261,12 @@ impl OpTrait for MoveParentSection {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Parent section".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Half page up")]
 pub(crate) struct HalfPageUp;
 impl OpTrait for HalfPageUp {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -256,10 +276,12 @@ impl OpTrait for HalfPageUp {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Half page up".into()
+    }
 }
 
-#[derive(Display)]
-#[display(fmt = "Half page down")]
 pub(crate) struct HalfPageDown;
 impl OpTrait for HalfPageDown {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -269,4 +291,8 @@ impl OpTrait for HalfPageDown {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Half page down".into()
+    }
 }
