@@ -1,10 +1,7 @@
 use super::{Action, OpTrait};
 use crate::{items::TargetData, screen, state::State, term::Term};
-use derive_more::Display;
 use std::rc::Rc;
 
-#[derive(Display)]
-#[display(fmt = "Show Refs")]
 pub(crate) struct ShowRefs;
 impl OpTrait for ShowRefs {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -13,6 +10,10 @@ impl OpTrait for ShowRefs {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "Show Refs".into()
+    }
 }
 
 fn goto_refs_screen(state: &mut State) {
