@@ -19,10 +19,8 @@ use std::io::Stderr;
 
 pub type Term = Terminal<TermBackend>;
 
-pub fn enter_alternate_screen() -> Res<()> {
-    stderr().execute(EnterAlternateScreen)?;
-    Ok(())
-}
+// TODO It would be more logical if the following top-level functions also were in 'TermBackend'.
+//      However left here for now.
 
 pub fn alternate_screen<T, F: Fn() -> Res<T>>(fun: F) -> Res<T> {
     stderr().execute(EnterAlternateScreen)?;
@@ -139,3 +137,12 @@ impl Backend for TermBackend {
         }
     }
 }
+
+impl TermBackend {
+    pub fn enter_alternate_screen(&mut self) -> io::Result<()> {
+        match self {
+            TermBackend::Crossterm(c) => c.execute(EnterAlternateScreen).map(|_| ()),
+            TermBackend::Test(_) => Ok(()),
+        }
+    }
+}
